@@ -1673,6 +1673,13 @@ sub apply {
             return 1;
         }
 
+        # support for @csv (format array/scalar as CSV row)
+        if ($part eq '@csv' || $part eq '@csv()') {
+            @next_results = map { JQ::Lite::Util::_apply_csv($_) } @results;
+            @$out_ref = @next_results;
+            return 1;
+        }
+
         # support for split("separator")
         if ($part =~ /^split\((.+)\)$/) {
             my $separator = JQ::Lite::Util::_parse_string_argument($1);
